package com.zanxiang.sdk.controller;

import com.zanxiang.common.domain.ResultVO;
import com.zanxiang.sdk.common.annotation.ValidLogin;
import com.zanxiang.sdk.domain.params.*;
import com.zanxiang.sdk.domain.vo.UserLoginVO;
import com.zanxiang.sdk.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author : lingfeng
 * @time : 2022-06-16
 * @description : 用户接口
 */
@Api(tags = "用户接口")
@RestController
@RequestMapping(value = "/api/user")
public class UserController {

    @Autowired
    private UserService userService;

    @Autowired
    private UserOauthService userOauthService;

    @Autowired
    private GameUserRoleService gameUserRoleService;

    @Autowired
    private GameUserService gameUserService;

    @Autowired
    private UserCardService userCardService;

    @ApiOperation(value = "忘记密码找回")
    @PostMapping("/find/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO<Boolean> findPassword(@Validated @RequestBody FindPasswordParam param) {
        return userService.findPassword(param);
    }

    @ApiOperation(value = "用户修改密码")
    @PostMapping("/update/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO<Boolean> updatePassword(@Validated @RequestBody UpdatePasswordParam param, @ValidLogin UserData userData) {
        return userService.updatePassword(param, userData);
    }

    @ApiOperation(value = "用户绑定手机")
    @PostMapping("/bind/phone")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO<Boolean> bindPhone(@Validated @RequestBody BindPhoneParam param, @ValidLogin UserData userData) {
        return userService.bindPhone(param, userData);
    }

    @ApiOperation(value = "用户实名认证")
    @PostMapping("/authentication")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO<Boolean> userAuthentication(@Validated @RequestBody UserCardUpdateParam param, @ValidLogin UserData userData) {
        return userCardService.userAuthentication(param, userData);
    }

    @ApiOperation(value = "用户获取信息详情")
    @PostMapping("/get/user/detail")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVO getUserDetail(@Validated @RequestBody UserDetailParam userDetailParam, UserData userData) {
        return userService.getUserDetail(userDetailParam, userData);
    }

//    @ApiOperation(value = "更新用户授权信息")
//    @PostMapping("/update/user/Oauth")
//    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
//    public ResultVO updateUserOauth(@Validated @RequestBody UserOauthlUpdateParam param, @ValidLogin UserData userData) {
//        return userOauthService.updateUserOauth(param, userData);
//    }
//
//    @ApiOperation(value = "创建/更新游戏用户")
//    @PostMapping("/update/game/user")
//    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
//    public ResultVO updateGameUser(@Validated @RequestBody GameUserUpdateParam param, @ValidLogin UserData userData) {
//        return ResultVO.ok(gameUserService.updateGameUser(param, userData));
//    }
//
//    @ApiOperation(value = "上传角色信息")
//    @PostMapping("/update/game/role")
//    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
//    public ResultVO updateUserGameRole(@Validated @RequestBody GameUserRoleUpdateParam param, @ValidLogin UserData userData) {
//        return ResultVO.ok(gameUserRoleService.updateUserGameRole(param, userData));
//    }
//
//    @ApiOperation(value = "用户信息检测")
//    @PostMapping("/check")
//    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
//    public ResultVO upUserGameRole(@Validated @RequestBody UserCheckParam param, @ValidLogin UserData userData) {
//        return ResultVO.ok(userService.userCheck(param, userData));
//    }

}
