package com.zanxiang.sdk.service.Impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.enums.ExpireTimeEnum;
import com.zanxiang.mybatis.entity.GameKey;
import com.zanxiang.mybatis.mapper.GameKeyMapper;
import com.zanxiang.sdk.common.constant.RedisKeyConstant;
import com.zanxiang.sdk.common.util.RedisUtil;
import com.zanxiang.sdk.service.GameKeyService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author : lingfeng
 * @time : 2022-09-23
 * @description : 游戏密钥
 */
@Slf4j
@Service
public class GameKeyServiceImpl extends ServiceImpl<GameKeyMapper, GameKey> implements GameKeyService {

    @Autowired
    private RedisUtil<GameKey> redisUtil;

    /**
     * 根据游戏id查询密钥
     *
     * @param gameId : 游戏id
     * @return : 返回游戏密钥
     */
    @Override
    public GameKey getByGameId(Long gameId) {
        //查询缓存
        GameKey gameKey = redisUtil.getCache(this.getGameKey(gameId));
        if (gameKey == null) {
            gameKey = this.getOne(new LambdaQueryWrapper<GameKey>().eq(GameKey::getGameId, gameId));
        }
        if (gameKey != null) {
            redisUtil.setCache(this.getGameKey(gameId), gameKey, ExpireTimeEnum.ONE_DAY.getTime());
        }
        return gameKey;
    }

    /**
     * 拼接用户token缓存key
     *
     * @param gameId : 游戏id
     * @return : 返回游戏key的缓存key
     */
    private String getGameKey(Long gameId) {
        return RedisKeyConstant.GAME_SECRET_KEY + "_" + gameId;
    }
}
