package com.zanxiang.sdk.service.Impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.domain.ResultVO;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.mybatis.entity.User;
import com.zanxiang.mybatis.entity.UserOauth;
import com.zanxiang.mybatis.mapper.UserOauthMapper;
import com.zanxiang.sdk.domain.dto.UserOauthDTO;
import com.zanxiang.sdk.domain.params.UserData;
import com.zanxiang.sdk.domain.params.UserOauthlUpdateParam;
import com.zanxiang.sdk.domain.vo.UserVO;
import com.zanxiang.sdk.service.UserOauthService;
import com.zanxiang.sdk.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Map;
import java.util.Objects;
import java.util.concurrent.Semaphore;

/**
 * @author : lingfeng
 * @time : 2022-06-21
 * @description : 用户第三方授权信息
 */
@Slf4j
@Service
public class UserOauthServiceImpl extends ServiceImpl<UserOauthMapper, UserOauth> implements UserOauthService {

    @Autowired
    private UserService userService;

    /**
     * 根据openid查询用户授权信息
     *
     * @param openId : 用户第三方授权信息
     * @return : 返回用户授权信息
     */
    @Override
    public UserOauthDTO getUserOauthByOpenId(String openId) {
        try {
            //根据用户第三方唯一查询
            UserOauth userOauth = super.getOne(new LambdaQueryWrapper<UserOauth>().eq(UserOauth::getOpenid, openId));
            //直接查到了信息
            if (userOauth != null) {
                return BeanUtils.copy(userOauth, UserOauthDTO.class);
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
        }
        return null;
    }

    /**
     * 创建用户授权信息
     *
     * @param user : 用户信息
     * @param map  : 第三方用户信息
     * @return : 返回用户授权信息
     */
    @Override
    public UserOauthDTO createUserOauth(User user, Map<String, String> map) {
        UserOauth userOauth = UserOauth.builder()
                .userId(user.getId())
                .openid(map.get("openId"))
                .accessToken(map.get("accessToken"))
                .unionid(map.get("openId"))
                .nickname(map.get("nickname"))
                .avatar(map.get("avatar"))
                .build();
        super.save(userOauth);
        return BeanUtils.copy(userOauth, UserOauthDTO.class);
    }

    @Override
    public ResultVO<UserVO> updateUserOauth(UserOauthlUpdateParam param, UserData userData) {
        UserOauthDTO userOauth = getUserOauthByOpenId(param.getUnionId());
        if (Objects.isNull(userOauth)) {
            return ResultVO.fail("授权登录不存在");
        }
        UserOauth data = BeanUtils.copy(param, UserOauth.class);
        data.setUserId(userData.getUserId());
        data.setId(userOauth.getId());
        super.updateById(data);
        User user = userService.getById(userData.getUserId());
        if (Objects.isNull(user)) {
            return ResultVO.fail("获取用户信息失败");
        }
        Semaphore semaphore = new Semaphore(10);
        return ResultVO.ok(BeanUtils.copy(user, UserVO.class));
    }
}
